@@ -543,70 +543,72 @@ def vasp_to_runner_data_train(finput, charges_default):
     samples = list_of_directories(finput)
     text = ''
     for sample in samples:
-        #charges and positions
-        file = open(finput + sample + '/ACF.dat')
-        lines = file.readlines()
-        file.close()
-        total_electrones = float(lines[-1].split()[-1])
-        lines = lines[2:-4]
-        positions = np.array([l.split()[1:4] for l in lines], dtype=float)*Angstrom_2_Bohr
-        positions = np.array(positions, dtype='str')
-        charges_ = np.array([l.split()[4] for l in lines], dtype=float)
+        try:
+            #charges and positions
+            file = open(finput + sample + '/ACF.dat')
+            lines = file.readlines()
+            file.close()
+            total_electrones = float(lines[-1].split()[-1])
+            lines = lines[2:-4]
+            positions = np.array([l.split()[1:4] for l in lines], dtype=float)*Angstrom_2_Bohr
+            positions = np.array(positions, dtype='str')
+            charges_ = np.array([l.split()[4] for l in lines], dtype=float)
 
-        file = open(finput + sample + '/POSCAR')
-        lines = file.readlines()
-        atoms = lines[6].split()
-        atoms_names = lines[5].split()
-        file.close()
-        atoms = [int(a) for a in atoms]
-        charges_default_vec = []
-        atoms_names_vec = []
-        for a, cd, an in zip(atoms, charges_default, atoms_names):
-            charges_default_vec = charges_default_vec + [cd]*a
-            atoms_names_vec = atoms_names_vec + [an]*a
-        charges_default_vec = np.array(charges_default_vec)
-        charges = (-charges_+charges_default_vec).tolist()
-        charges = [str(c) for c in charges]
-        basis = lines[2:5]
+            file = open(finput + sample + '/POSCAR')
+            lines = file.readlines()
+            atoms = lines[6].split()
+            atoms_names = lines[5].split()
+            file.close()
+            atoms = [int(a) for a in atoms]
+            charges_default_vec = []
+            atoms_names_vec = []
+            for a, cd, an in zip(atoms, charges_default, atoms_names):
+                charges_default_vec = charges_default_vec + [cd]*a
+                atoms_names_vec = atoms_names_vec + [an]*a
+            charges_default_vec = np.array(charges_default_vec)
+            charges = (-charges_+charges_default_vec).tolist()
+            charges = [str(c) for c in charges]
+            basis = lines[2:5]
 
-        #forces
-        file = open(finput + sample + '/OUTCAR')
-        lines = file.readlines()[2:-4]
-        file.close()
-        energy = [l for l in lines if 'energy  without entropy' in l]
-        energy = str(float(energy[-1].split('=')[1].split()[0])*ev2H)
+            #forces
+            file = open(finput + sample + '/OUTCAR')
+            lines = file.readlines()[2:-4]
+            file.close()
+            energy = [l for l in lines if 'energy  without entropy' in l]
+            energy = str(float(energy[-1].split('=')[1].split()[0])*ev2H)
 
-        start = [i for i in range(len(lines)) if 'TOTAL-FORCE' in lines[i]]
-        lines = lines[start[-1]+2:]
-        stop = [i for i in range(len(lines)) if 'total drift:' in lines[i]]
-        lines = lines[:stop[-1]-1]
-        forces = np.array([l.split()[3:] for l in lines], dtype=float)
-        forces = np.array(forces*eV_per_Angstrom_2_Ha_per_Bohr, dtype='str')
-
-        text = text + 'begin\n'
-        text = text + 'lattice         '+'   '.join((np.array(np.array(basis[0].split(), dtype=float)*Angstrom_2_Bohr, dtype=str)).tolist()) + '\n'
-        text = text + 'lattice         '+'   '.join((np.array(np.array(basis[1].split(), dtype=float)*Angstrom_2_Bohr, dtype=str)).tolist()) + '\n'
-        text = text + 'lattice         '+'   '.join((np.array(np.array(basis[2].split(), dtype=float)*Angstrom_2_Bohr, dtype=str)).tolist()) + '\n'
-        lines = ''
-        for i in range(len(atoms_names_vec)):
-            line = [
-                    'atom',
-                    ("%.10f" % float(positions[i][0])),
-                    ("%.10f" % float(positions[i][1])),
-                    ("%.10f" % float(positions[i][2])),
-                    atoms_names_vec[i],
-                    ("%.10f" % float(charges[i])),
-                    '0',
-                    ("%.10f" % float(forces[i][0])),
-                    ("%.10f" % float(forces[i][1])),
-                    ("%.10f" % float(forces[i][2])),
-                    ]
-            lines = lines + ''.join(word.ljust(15) for word in line)+'\n'
-        text = text + lines
-        text = text + 'energy    ' + energy + '\n'
-        text = text + 'charge    '+str(-np.sum(charges_default_vec)+total_electrones)+ '\n'
-        text = text + 'end\n'
+            start = [i for i in range(len(lines)) if 'TOTAL-FORCE' in lines[i]]
+            lines = lines[start[-1]+2:]
+            stop = [i for i in range(len(lines)) if 'total drift:' in lines[i]]
+            lines = lines[:stop[-1]-1]
+            forces = np.array([l.split()[3:] for l in lines], dtype=float)
+            forces = np.array(forces*eV_per_Angstrom_2_Ha_per_Bohr, dtype='str')
 
+            text = text + 'begin\n'
+            text = text + 'lattice         '+'   '.join((np.array(np.array(basis[0].split(), dtype=float)*Angstrom_2_Bohr, dtype=str)).tolist()) + '\n'
+            text = text + 'lattice         '+'   '.join((np.array(np.array(basis[1].split(), dtype=float)*Angstrom_2_Bohr, dtype=str)).tolist()) + '\n'
+            text = text + 'lattice         '+'   '.join((np.array(np.array(basis[2].split(), dtype=float)*Angstrom_2_Bohr, dtype=str)).tolist()) + '\n'
+            lines = ''
+            for i in range(len(atoms_names_vec)):
+                line = [
+                        'atom',
+                        ("%.10f" % float(positions[i][0])),
+                        ("%.10f" % float(positions[i][1])),
+                        ("%.10f" % float(positions[i][2])),
+                        atoms_names_vec[i],
+                        ("%.10f" % float(charges[i])),
+                        '0',
+                        ("%.10f" % float(forces[i][0])),
+                        ("%.10f" % float(forces[i][1])),
+                        ("%.10f" % float(forces[i][2])),
+                        ]
+                lines = lines + ''.join(word.ljust(15) for word in line)+'\n'
+            text = text + lines
+            text = text + 'energy    ' + energy + '\n'
+            text = text + 'charge    '+str(-np.sum(charges_default_vec)+total_electrones)+ '\n'
+            text = text + 'end\n'
+        except()
+            print('problems with '+sample)
     file = open(finput + '/input.data', 'w')
     file.writelines(text)
     file.close()
\ No newline at end of file
